<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appaboutpage.cpp" line="38"/>
        <source>&lt;p align=center&gt;&lt;b&gt;Welcome to FreeMedForms&lt;/b&gt;&lt;br /&gt;(C) 2008-%1 by Eric MAEKER, MD&lt;/p&gt;&lt;p align=left&gt;This software is release without any warranty and only for test purposal.&lt;br /&gt;Please refer to web site for more informations.&lt;br /&gt;&lt;a href=&quot;%2&quot;&gt;Web site&lt;/a&gt;&lt;/p&gt;</source>
        <translation>&lt;p align=center&gt;&lt;b&gt;Bienvenu sur FreeMedForms&lt;/b&gt;&lt;br /&gt;(C) 2008-%1 par Dr Eric MAEKER&lt;/p&gt;&lt;p align=left&gt;Ce logiciel est fourni sans aucune garantie et pour uniquement à des fins de test.&lt;br /&gt;Veuillez vous reférer au site internet du projet pour plus d&apos;informations.&lt;br /&gt;&lt;a href=&quot;%2&quot;&gt;Web site&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Core::AppConfigWizard</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="119"/>
        <source>Application Configurator Wizard</source>
        <translation>Assistant de configuration</translation>
    </message>
</context>
<context>
    <name>Core::ClientConfigPage</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="272"/>
        <source>Personnal login and password</source>
        <translation>Identifiants personnels</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="285"/>
        <source>Network client configuration</source>
        <translation>Configuration réseau en tant que client</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="286"/>
        <source>There were no automatic server configuration file found.&lt;br /&gt;You must configure the server manually.&lt;br /&gt;Use your &lt;b&gt;personnal login and password&lt;/b&gt; to connect the database.</source>
        <translation>Il n&apos;existe aucun fichier de configuration automatique de réseau.&lt;br /&gt;Vous devez configurer le serveur manuellement.&lt;br /&gt;Utilisez vos &lt;b&gt;identifiants personnels&lt;/b&gt; pour vous connecter au serveur de données.</translation>
    </message>
</context>
<context>
    <name>Core::CoreConfigPage</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="194"/>
        <source>Welcome to %1</source>
        <translation>Bienvenue, %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="195"/>
        <source>&lt;b&gt;Welcome to %1&lt;/b&gt;&lt;br /&gt;&lt;br /&gt;This wizard will help you to configure the base parameters of the application.&lt;br /&gt;At any time, you can cancel this wizard, the default values will be activated for the undefined parameters.</source>
        <translation>&lt;b&gt;Bienvenu, %1&lt;/b&gt;&lt;br /&gt;&lt;br /&gt;Cet assistants va vous aider à configurer les paramètres de base de l&apos;application.&lt;br /&gt;À tout moment, vous pouvez annuler l&apos;assistant qui utilisera alors les valeurs par défaut pour les paramètres non définis.</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="203"/>
        <source>Select your language</source>
        <translation>Sélectionnez votre langue</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="204"/>
        <source>Select the type of installation</source>
        <translation>Sélectionnez le type d&apos;installation</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="207"/>
        <source>Single computer</source>
        <translation>Mono-poste</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="209"/>
        <source>Network (as client)</source>
        <translation>Réseau (en tant que client)</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="210"/>
        <source>Network (as server)</source>
        <translation>Réseau (en tant que serveur)</translation>
    </message>
</context>
<context>
    <name>Core::EndConfigPage</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="534"/>
        <source>%1 is now configured</source>
        <translation>%1 est maintenant configuré</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="535"/>
        <source>Please read the user&apos;s manual. If you have any question, you can ask them to the mailing list.</source>
        <translation>Veuillez vous reporter au manuel de l&apos;utilisateur. Si vous avez des question, vous pouvez les poser sur notre liste de diffusion.</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="539"/>
        <source>You can clean and recreate all your databases. Select the option above. If you select the clean option, all databases will be erased with &lt;b&gt;definitive data lose&lt;/b&gt;.</source>
        <translation>Vous pouvez nettoyer et recréer toutes vos bases de données. Pour ce faire, sélectionnez cette option. Si vous sélectionnez cette option, toutes les bases de données seront effacées avec des &lt;b&gt;pertes définitives de données&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="544"/>
        <source>Don&apos;t clean databases</source>
        <translation>Ne pas nettoyer les bases</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="544"/>
        <source>Clean and recreate database</source>
        <translation>Nettoyer et recréer les bases</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="547"/>
        <source>You can create virtual data to test the application. Select the option above.</source>
        <translation>Vous pouvez créer des données virtuelles pour tester l&apos;application. Sélectionnez l&apos;option ci-dessous.</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="550"/>
        <source>Don&apos;t create virtual data</source>
        <translation>Ne pas créer les données virtuelles</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="550"/>
        <source>Create virtual data</source>
        <translation>Créer les données virtuelles</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="552"/>
        <source>French/english mailing list</source>
        <translation>Liste de diffusion française/anglaise</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="555"/>
        <source>Application main web site</source>
        <translation>Site internet de l&apos;application</translation>
    </message>
</context>
<context>
    <name>Core::ICore</name>
    <message>
        <location filename="../../plugins/coreplugin/icore.cpp" line="64"/>
        <source>You are running an alpha version of %1. This version can be heavily buggy and is only provided for testing purpose.</source>
        <translation>Vous utilisez une version alpha de %1. Cette version peut être sérieusement bogguée et n&apos;est proposée que pour des fins de test.</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/icore.cpp" line="70"/>
        <source>If you found any problem with %1, please report it on our mailing list: &lt;a href=&quot;mailto:freemedforms@googlegroups.com&gt;freemedforms@googlegroups.com&lt;/a&gt;</source>
        <translation>Si vous rencontrez un problème quelconque avec %1, veuillez le notifier sur la liste de diffusion : &lt;a href=&quot;mailto:freemedforms@googlegroups.com&gt;freemedforms@googlegroups.com&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/icore.cpp" line="74"/>
        <source>Warning alpha version</source>
        <translation>Attention version alpha</translation>
    </message>
</context>
<context>
    <name>Core::Internal::AboutDialog</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/aboutdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/aboutdialog.ui" line="50"/>
        <source>Application name</source>
        <translation>Nom de l&apos;application</translation>
    </message>
</context>
<context>
    <name>Core::Internal::AppAboutPage</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appaboutpage.h" line="56"/>
        <source>1. General</source>
        <translation>1. Général</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appaboutpage.h" line="57"/>
        <source>Application</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Core::Internal::ApplicationGeneralPreferencesWidget</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="20"/>
        <source>Update engine</source>
        <translation>Moteur de mise à jour</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="32"/>
        <source>Update checking</source>
        <translation>Vérification des mises à jour</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="40"/>
        <source>At startup</source>
        <translation>Au démarrage</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="45"/>
        <source>Each weeks</source>
        <translation>Toutes les semaines</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="50"/>
        <source>Each months</source>
        <translation>Tous les mois</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="55"/>
        <source>Each quarters</source>
        <translation>Tous les trimestres</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="60"/>
        <source>Never (on user&apos;s demand)</source>
        <translation>Jamais (à la demande)</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="84"/>
        <source>Database Management</source>
        <translation>Pilotage des bases de données</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="102"/>
        <source>Automatically save data without prompting users</source>
        <translation>Toujours sauvegarder automatiquement les données</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="109"/>
        <source>Allow and use virtual data</source>
        <translation>Autoriser l&apos;utilisation des données virtuelles</translation>
    </message>
</context>
<context>
    <name>Core::Internal::BuildAboutPage</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.cpp" line="90"/>
        <source>Actual Qt version : %1</source>
        <translation>Version actuelle de Qt : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="43"/>
        <source>4. Build information</source>
        <translation>4. Informations de compilation</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="44"/>
        <source>Application</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Core::Internal::CoreImpl</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/coreimpl.cpp" line="146"/>
        <location filename="../../plugins/fmfcoreplugin/coreimpl.cpp" line="148"/>
        <source>Core intialization finished...</source>
        <translation>Intialisation du Core terminée...</translation>
    </message>
</context>
<context>
    <name>Core::Internal::CorePlugin</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/coreplugin.cpp" line="76"/>
        <location filename="../../plugins/fmfcoreplugin/coreplugin.cpp" line="97"/>
        <source>Initializing core plugin...</source>
        <translation>Initialisation du plugin central...</translation>
    </message>
</context>
<context>
    <name>Core::Internal::DebugDialog</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.ui" line="28"/>
        <source>Send to dev team</source>
        <translation>Envoyer à l&apos;équipe de développement</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.ui" line="35"/>
        <source>Save log</source>
        <translation>Enregistrer le journal</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.ui" line="61"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.ui" line="74"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="101"/>
        <source>Sending debugging information to dev team</source>
        <translation>Envoyer les informations de déboggage à l&apos;équipe de développement</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="102"/>
        <source>Trying to send information to dev team.
Using Url : %1 
Please wait...</source>
        <translation>Essaye d&apos;envoyer les informations à l&apos;équipe de développement.
Url : %1
Veuillez patienter...</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="123"/>
        <source>Debugging information correctly sent.</source>
        <translation>Informations de déboggage correctement envoyées.</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="126"/>
        <source>Debugging information correctly send to dev team.
Using Url : %1 
%2</source>
        <translation>Informations de déboggage correctement envoyées à l&apos;équipe de développement.
Url: %1
%2</translation>
    </message>
</context>
<context>
    <name>Core::Internal::LicenseAboutPage</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="57"/>
        <source>3. License</source>
        <translation>3. Licence</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="58"/>
        <source>Application</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Core::Internal::PageWidget</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/pagewidget.ui" line="14"/>
        <source>Options</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/pagewidget.ui" line="40"/>
        <source>0</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Core::Internal::ServerPreferencesWidget</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="29"/>
        <source>Test connection</source>
        <translation>Tester la connection</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="43"/>
        <source>Database server</source>
        <translation>Serveur de données</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="55"/>
        <source>Server type</source>
        <translation>Type de serveur</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="66"/>
        <source>MySQL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="80"/>
        <source>Host name</source>
        <translation>Nom de l&apos;hôte</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="100"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="120"/>
        <source>Test host connection</source>
        <translation>Tester la connexion à l&apos;hôte</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="130"/>
        <source>User identification</source>
        <translation>Identification de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="142"/>
        <source>Login</source>
        <translation>Identifiant</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="162"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.ui" line="176"/>
        <source>Use the default FreeMedForms administrator</source>
        <translation>Utiliser l&apos;administrateur par défaut de FreeMedForms</translation>
    </message>
</context>
<context>
    <name>Core::Internal::SettingDebugPage</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/commondebugpages.h" line="78"/>
        <location filename="../../plugins/coreplugin/dialogs/commondebugpages.h" line="79"/>
        <source>Settings</source>
        <translation>Préférences</translation>
    </message>
</context>
<context>
    <name>Core::Internal::SettingsDialog</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/settingsdialog.ui" line="14"/>
        <source>Options</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Core::Internal::SettingsPrivate</name>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="723"/>
        <source>Passing command line ini file : %1</source>
        <translation>Fichier INI spécifié : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="732"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="761"/>
        <source>Using ini file %1.</source>
        <translation>Utilise le fichier INI %1.</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="736"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="765"/>
        <source>Ini file %1 is not writable. Can not use it.</source>
        <translation>Le fichier %1 n&apos;est pas accessible en écriture. Impossible de l&apos;utiliser.</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="741"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="770"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="813"/>
        <source>Using ini file %1</source>
        <translation>Utilise le fichier INI %1</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="745"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="774"/>
        <source>WARNING : Ini file %1 can not be used.</source>
        <translation>ATTENTION : fichier INI %1 ne peut pas être utiliser.</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="802"/>
        <source>Trying ini file %1</source>
        <translation>Essaie le fichier INI %1</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="808"/>
        <source>Unable to create dir : %1, no Ini File can be used.</source>
        <translation>Impossible de créer le répertoire %1, aucun fichier INI ne peut être utiliser.</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="910"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="910"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="917"/>
        <source>Operating System</source>
        <translation>Système d&apos;exploitation</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="919"/>
        <source>uname output</source>
        <translation>Sortie de uname</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="925"/>
        <source>Compilation Date</source>
        <translation>Date de compilation</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="926"/>
        <source>Compile Qt version</source>
        <translation>Version de Qt (compilation)</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="927"/>
        <source>Actual Qt version</source>
        <translation>Version actuelle de Qt</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="930"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="932"/>
        <source>Compile mode</source>
        <translation>Mode de compilation</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="939"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1046"/>
        <source>Binary</source>
        <translation>Binaire</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="940"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1047"/>
        <source>Resources</source>
        <translation>Ressources</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="941"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1048"/>
        <source>Read only Databases</source>
        <translation>Bases de données en lecture seule</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="942"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1049"/>
        <source>Writable databases</source>
        <translation>Bases de données en écriture</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="943"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1050"/>
        <source>Bundle root path</source>
        <translation>Répertoire du bundle</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="944"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1051"/>
        <source>Bundle resources path</source>
        <translation>Répertoire resources du paquet</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="945"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1052"/>
        <source>Translations path</source>
        <translation>Répertoire des traductions</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="946"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1053"/>
        <source>Qt Plugins path</source>
        <translation>Répertoire des plugins de Qt</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="947"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1054"/>
        <source>Qt FrameWorks path</source>
        <translation>Répertoire des bibliothèques Qt</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="948"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1055"/>
        <source>FreeMedForms PlugIns path</source>
        <translation>Répertoire des plugins de FreeMedForms</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="949"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1056"/>
        <source>SmallPixmapPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="950"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1057"/>
        <source>MediumPixmapPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="951"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1058"/>
        <source>BigPixmapPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="952"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1059"/>
        <source>SystemTempPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="953"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1060"/>
        <source>ApplicationTempPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="954"/>
        <source>CompleteFormsPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="955"/>
        <source>SubFormsPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1027"/>
        <source>SVN version : %1
</source>
        <translation>Version SVN: %1
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1061"/>
        <source>FormsPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1062"/>
        <source>SampleFormsPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="956"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1063"/>
        <source>DocumentationPath</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="915"/>
        <source>System information</source>
        <translation>Informations système</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="933"/>
        <source>SVN version</source>
        <translation>Version SVN</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="958"/>
        <source>Absolute Paths</source>
        <translation>Chemins absolus</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="960"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="964"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1030"/>
        <source>Using Ini File</source>
        <translation>Fichier ini</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="962"/>
        <source>Relative Paths</source>
        <translation>Chemins relatifs</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="970"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="971"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1064"/>
        <source>WebSiteUrl</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="977"/>
        <source>Settings values</source>
        <translation>Valeurs des paramètres</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="980"/>
        <source>Orphan settings</source>
        <translation>Paramètres orphelins</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1018"/>
        <source>Running version : %1
</source>
        <translation>Version en cours : %1
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1019"/>
        <source>Build date : %1 %2
</source>
        <translation>Date de compilation : %1 %2
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1020"/>
        <source>Qt Build version : %1
</source>
        <translation>Version de Qt à la compilation : %1
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1021"/>
        <source>Qt running version : %1
</source>
        <translation>Version de Qt en cours : %1
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1022"/>
        <source>Application Version : %1
</source>
        <translation>Version de l&apos;application : %1
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1024"/>
        <source>Actual build : Debug
</source>
        <translation>Configuration actuelle : Debug
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1026"/>
        <source>Actual build : Release
</source>
        <translation>Configuration actuelle : Release
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1028"/>
        <source>Application path : %1
</source>
        <translation>Chemin de l&apos;application : %1
</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1032"/>
        <source>Running on Linux</source>
        <translation>Utilisation sur Linux</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1033"/>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1037"/>
        <source>   uname returns : %1</source>
        <translation>   information &apos;uname&apos; : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1036"/>
        <source>Running on MacOs</source>
        <translation>Utilisation sur MacOs</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/settings.cpp" line="1040"/>
        <source>Running on Windows</source>
        <translation>Utilisation sur Windows</translation>
    </message>
</context>
<context>
    <name>Core::Internal::SimpleTextDialog</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/simpletextdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/simpletextdialog.ui" line="34"/>
        <source>title</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Core::Internal::TeamAboutPage</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="71"/>
        <source>2. Team</source>
        <translation>2. Équipe</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="72"/>
        <source>Application</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Core::ModeManager</name>
    <message>
        <location filename="../../plugins/coreplugin/modemanager/modemanager.cpp" line="168"/>
        <source>Switch to %1 mode</source>
        <translation>Passer au mode %1</translation>
    </message>
</context>
<context>
    <name>Core::PageWidget</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/pagewidget.cpp" line="347"/>
        <source>Full view</source>
        <translation>Vue étendue</translation>
    </message>
</context>
<context>
    <name>Core::PluginDialog</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="56"/>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="57"/>
        <source>Error Details</source>
        <translation>Détails des erreurs</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="58"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="72"/>
        <source>Installed Plugins</source>
        <translation>Plugins installés</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="111"/>
        <source>Plugin Details of %1</source>
        <translation>Détails du plugin %1</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="131"/>
        <source>Plugin Errors of %1</source>
        <translation>Détail des erreurs du plugin %1</translation>
    </message>
</context>
<context>
    <name>Core::ServerConfigPage</name>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="342"/>
        <source>Network server configuration</source>
        <translation>Configuration réseau : serveur</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="343"/>
        <source>There were no automatic server configuration file found.&lt;br /&gt;You must configure the server manually.&lt;br /&gt;Use the &lt;b&gt;server super-administrator login and password&lt;/b&gt; to connect the database.</source>
        <translation>Il n&apos;existe aucun fichier de configuration automatique de réseau.&lt;br /&gt;Vous devez configurer le serveur manuellement.&lt;br /&gt;Utilisez les &lt;b&gt;identifiants du super-utilisateur réseau&lt;/b&gt; pour vous connecter au serveur de données.</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="346"/>
        <source>Server super-administrator login and password</source>
        <translation>Identifiants du super-utilisateur réseau</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="367"/>
        <source>Connection to the server: User rights inadequate</source>
        <translation>Connexion au serveur : droits d&apos;utilisateur inadéquat</translation>
    </message>
    <message>
        <location filename="../../plugins/fmfcoreplugin/appconfigwizard.cpp" line="368"/>
        <source>You need to connect with another user that have rights to select, udpate, delete, insert, create, drop, alter and create user.
Please contact your server administrator.</source>
        <translation>Vous devez vous connecter avec un autre utilisateur qui les droits suivants : select, udpate, delete, insert, create, drop, alter and create user.
Veuillez contacter votre administrateur réseau.</translation>
    </message>
</context>
<context>
    <name>Core::ServerPreferencesWidget</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.cpp" line="175"/>
        <source>Host name error (%1:%2)</source>
        <translation>Erreur de l&apos;hôte (%1: %2)</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.cpp" line="213"/>
        <source>Host not reachable...</source>
        <translation>Hôte non joignable...</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.cpp" line="217"/>
        <source>No anonymous connection allowed</source>
        <translation>Les connexion anonymes sont interdites</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.cpp" line="220"/>
        <source>Test in progress...</source>
        <translation>Test en cours...</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.cpp" line="234"/>
        <source>Connection error: %1</source>
        <translation>Erreur de connexion : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/serverpreferenceswidget.cpp" line="240"/>
        <source>Connected</source>
        <translation>Connecté</translation>
    </message>
</context>
<context>
    <name>Core::SettingsDialog</name>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/settingsdialog.cpp" line="65"/>
        <source>Apply all changes (all pages)</source>
        <translation>Appliquer tous les changements (toutes les pages)</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/dialogs/settingsdialog.cpp" line="66"/>
        <source>Reset to default the current page</source>
        <translation>Réinitialiser les valeurs par défaut sur la page courante</translation>
    </message>
</context>
<context>
    <name>Core::Translators</name>
    <message>
        <location filename="../../plugins/coreplugin/translators.cpp" line="139"/>
        <source>Can not load %1, path : %2</source>
        <translation>Impossible de charger %1, chemin %2</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/translators.cpp" line="182"/>
        <source>Add Translator %1.</source>
        <translation>Ajout du dictionnaire de traductions %1.</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/translators.cpp" line="189"/>
        <source>WARNING : Can not be loaded %1 or already loaded.</source>
        <translation>Attention : impossible de charger %1 ou déjà chargé.</translation>
    </message>
</context>
<context>
    <name>ThemePrivate</name>
    <message>
        <location filename="../../plugins/coreplugin/theme.cpp" line="171"/>
        <source>ERROR - Theme : Unable to load icon file %1</source>
        <translation>ERREUR - Thème : impossible de charger l&apos;icône %1</translation>
    </message>
</context>
<context>
    <name>tkConstants</name>
    <message>
        <location filename="../../plugins/coreplugin/constants.h" line="44"/>
        <source>FreeDiams Prescriptions (*.di)</source>
        <translation>Prescriptions FreeDiams (*.di)</translation>
    </message>
    <message>
        <location filename="../../plugins/coreplugin/constants.h" line="45"/>
        <source>FreeMedForms Forms File (*.xml)</source>
        <translation>Fichier Formulaire FreeMedForms (*.xml)</translation>
    </message>
</context>
</TS>
